package com.winhc.bigdata.spark.utils

import scala.collection.mutable
import java.util.{Calendar, Date, Locale}
import org.apache.commons.lang3.time.DateFormatUtils
import org.apache.spark.sql.SparkSession

/**
 * @Author: XuJiakai
 * @Date: 2020/6/3 18:49
 * @Description:
 */
object BaseUtil {
  def isWindows: Boolean = System.getProperty("os.name").contains("Windows")

  def getExecutorConfigOrExit(args: Array[String]): mutable.Map[String, String] = {
    if (args.length != 3) {
      println("请配置计算资源: instances, cores, memory .")
      sys.exit(-1)
    }
    val Array(instances, cores, memory) = args;
    getExecutorConfig(instances, cores, memory)
  }

  def getExecutorConfigOrDefault(args: Array[String]): mutable.Map[String, String] = {
    var instances, cores, memory: String = null
    if (args.length != 3) {
      println("使用默认的计算资源: 2 instances, 2 cores, 10g memory.")
      instances = "2"
      cores = "2"
      memory = "10g"
    } else {
      instances = args(0)
      cores = args(1)
      memory = args(2)
    }
    getExecutorConfig(instances, cores, memory)
  }

  private def getExecutorConfig(instances: String, cores: String, memory: String): mutable.Map[String, String] = {
    println(
      s"""
         |instances : $instances,
         |cores : $cores,
         |memory : $memory
         |""".stripMargin)
    mutable.Map("spark.executor.instances" -> instances,
      "spark.executor.cores" -> cores,
      "spark.executor.memory" -> memory
    )
  }
  def getPartion(t: String, @transient spark: SparkSession) = {
    import spark.implicits._
    import spark._
    val sql_s = s"show partitions " + t
    sql(sql_s).collect.toList.map(_.getString(0).split("=")(1)).last
  }

  def atMonthsBefore(n: Int, pattern: String = "yyyy-MM-dd"): String = {
    val c = Calendar.getInstance(Locale.CHINA)
    c.setTimeInMillis(new Date().getTime)
    c.add(Calendar.MONTH, -1 * n)
    DateFormatUtils.format(c.getTime.getTime, pattern)
  }

}
